@@ -13,8 +13,7 @@ def encrypt_value(value):
 class Permission(Document):
     name = schema.StringProperty(required=True)
 
-class Group(Document):
-    name = schema.StringProperty(required=True)
+class Group(Permission):
     permissions = schema.SchemaListProperty(Permission)
 
 class User(Document):
@@ -26,13 +25,17 @@ class User(Document):
 
     @classmethod
     def authenticate(cls, username, password):
-        users = cls.view('user/by_name', key=username)
+        """Use view ``auth/user_by_name`` to check authentification.
+        Return a :class:`~repoze.what.plugins.couchdbkit.documents.User` object on success.
+        """
+        users = cls.view('auth/user_by_name', key=username)
         for user in users:
             if user and user.active and encrypt_value(password) == user.password:
                 return user
             break
 
     def encrypt_password(self):
+        """Encrypt password whith sha1 if not already done"""
         if self.password and self.password != self.password_check:
             self.password = encrypt_value(self.password)
             self.password_check = self.password
